import pandas as pd
from pathlib import Path
from sqlalchemy import create_engine, text

from ..utils import as_path

__all__= ['create_dbs','df_to_sql']

CHURN_TBL_DEFINITION = """\
tld TEXT,
log_dt INTEGER,
created INTEGER,
deleted INTEGER,
modified INTEGER,
prior_log_dt INTEGER,
PRIMARY KEY (tld, log_dt)
"""

def create_dbs(db_dir,device):
    db_dir = as_path(db_dir)
    db_dir.mkdir(exist_ok=True,parents=True)
    db_path = db_dir.joinpath(f"{device}.db")
    engine = create_engine(f"sqlite:///{db_path}")
    with engine.connect() as conn:
        conn.execute(text(f"CREATE TABLE IF NOT EXISTS churn ({CHURN_TBL_DEFINITION})"))
        conn.execute(text("CREATE INDEX IF NOT EXISTS churn_idx ON churn (tld, log_dt)"))

def df_to_sql(df: pd.DataFrame, path: Path | str, table: str):
    path = as_path(path)
    engine = create_engine(f"sqlite:///{path}")
    df.to_sql(table,engine,if_exists='append',index=False)